http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/configuration/IgniteConfiguration.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/configuration/IgniteConfiguration.java
 
b/modules/core/src/main/java/org/apache/ignite/configuration/IgniteConfiguration.java
index 778ca62..7b120c5 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/configuration/IgniteConfiguration.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/configuration/IgniteConfiguration.java
@@ -674,7 +674,7 @@ public class IgniteConfiguration {
      * Gets custom license file URL to be used instead of default license file 
location.
      *
      * @return Custom license file URL or {@code null} to use the default
-     *      {@code $GRIDGAIN_HOME}-related location.
+     *      {@code $IGNITE_HOME}-related location.
      */
     public String getLicenseUrl() {
         return licUrl;
@@ -1348,8 +1348,8 @@ public class IgniteConfiguration {
 
     /**
      * Should return GridGain installation home folder. If not provided, the 
system will check
-     * {@code GRIDGAIN_HOME} system property and environment variable in that 
order. If
-     * {@code GRIDGAIN_HOME} still could not be obtained, then grid will not 
start and exception
+     * {@code IGNITE_HOME} system property and environment variable in that 
order. If
+     * {@code IGNITE_HOME} still could not be obtained, then grid will not 
start and exception
      * will be thrown.
      *
      * @return GridGain installation home or {@code null} to make the system 
attempt to
@@ -1373,10 +1373,10 @@ public class IgniteConfiguration {
 
     /**
      * Gets GridGain work folder. If not provided, the method will use work 
folder under
-     * {@code GRIDGAIN_HOME} specified by {@link 
IgniteConfiguration#setGridGainHome(String)} or
-     * {@code GRIDGAIN_HOME} environment variable or system property.
+     * {@code IGNITE_HOME} specified by {@link 
IgniteConfiguration#setGridGainHome(String)} or
+     * {@code IGNITE_HOME} environment variable or system property.
      * <p>
-     * If {@code GRIDGAIN_HOME} is not provided, then system temp folder is 
used.
+     * If {@code IGNITE_HOME} is not provided, then system temp folder is used.
      *
      * @return GridGain work folder or {@code null} to make the system attempt 
to infer it automatically.
      * @see IgniteConfiguration#getGridGainHome()
@@ -2315,7 +2315,7 @@ public class IgniteConfiguration {
     }
 
     /**
-     * Sets path, either absolute or relative to {@code GRIDGAIN_HOME}, to 
{@code JETTY}
+     * Sets path, either absolute or relative to {@code IGNITE_HOME}, to 
{@code JETTY}
      * XML configuration file. {@code JETTY} is used to support REST over HTTP 
protocol for
      * accessing GridGain APIs remotely.
      *
@@ -2328,7 +2328,7 @@ public class IgniteConfiguration {
     }
 
     /**
-     * Gets path, either absolute or relative to {@code GRIDGAIN_HOME}, to 
{@code Jetty}
+     * Gets path, either absolute or relative to {@code IGNITE_HOME}, to 
{@code Jetty}
      * XML configuration file. {@code Jetty} is used to support REST over HTTP 
protocol for
      * accessing GridGain APIs remotely.
      * <p>
@@ -2700,7 +2700,7 @@ public class IgniteConfiguration {
      * a log file, file path is checked against this list. If requested file 
is not located in any
      * sub-folder of these folders, request is not processed.
      * <p>
-     * By default, list consists of a single {@code GRIDGAIN_HOME} folder. If 
{@code GRIDGAIN_HOME}
+     * By default, list consists of a single {@code IGNITE_HOME} folder. If 
{@code IGNITE_HOME}
      * could not be detected and property is not specified, no restrictions 
applied.
      *
      * @return Array of folders that are allowed be read by remote clients.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/configuration/IgniteDeploymentMode.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/configuration/IgniteDeploymentMode.java
 
b/modules/core/src/main/java/org/apache/ignite/configuration/IgniteDeploymentMode.java
index 0ce60d2..e14066c 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/configuration/IgniteDeploymentMode.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/configuration/IgniteDeploymentMode.java
@@ -48,7 +48,7 @@ import org.jetbrains.annotations.*;
  *    &lt;/bean>
  * </pre>
  * By default, all gridgain startup scripts ({@code gridgain.sh} or {@code 
gridgain.bat})
- * pick up user version from {@code GRIDGAIN_HOME/config/userversion} folder. 
Usually, it
+ * pick up user version from {@code IGNITE_HOME/config/userversion} folder. 
Usually, it
  * is just enough to update user version under that folder, however, in case 
of {@code GAR}
  * or {@code JAR} deployment, you should remember to provide {@code 
META-INF/gridgain.xml}
  * file with desired user version in it.
@@ -61,7 +61,7 @@ import org.jetbrains.annotations.*;
  * <ol>
  *  <li>
  *      Simply startup stand-alone GridGain nodes by executing
- *      {@code GRIDGAIN_HOME/ggstart.{sh|bat}} scripts.
+ *      {@code IGNITE_HOME/ggstart.{sh|bat}} scripts.
  *  </li>
  *  <li>
  *      Now, all jobs executing locally or remotely can have a single instance 
of cache

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsConfiguration.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsConfiguration.java 
b/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsConfiguration.java
index 37b6518..5ff041d 100644
--- a/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsConfiguration.java
+++ b/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsConfiguration.java
@@ -412,7 +412,7 @@ public class IgniteFsConfiguration {
      *     <li>{@code port} - endpoint port.</li>
      *     <li>{@code size} - memory size allocated for single endpoint 
communication.</li>
      *     <li>
-     *         {@code tokenDirectoryPath} - path, either absolute or relative 
to {@code GRIDGAIN_HOME} to
+     *         {@code tokenDirectoryPath} - path, either absolute or relative 
to {@code IGNITE_HOME} to
      *         store shared memory tokens.
      *     </li>
      * </ul>

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/internal/GridGainEx.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/internal/GridGainEx.java 
b/modules/core/src/main/java/org/apache/ignite/internal/GridGainEx.java
index 61af15e..53d4d63 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/GridGainEx.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/GridGainEx.java
@@ -401,7 +401,7 @@ public class GridGainEx {
 
     /**
      * Starts grid with default configuration. By default this method will
-     * use grid configuration defined in {@code 
GRIDGAIN_HOME/config/default-config.xml}
+     * use grid configuration defined in {@code 
IGNITE_HOME/config/default-config.xml}
      * configuration file. If such file is not found, then all system defaults 
will be used.
      *
      * @return Started grid.
@@ -414,7 +414,7 @@ public class GridGainEx {
 
     /**
      * Starts grid with default configuration. By default this method will
-     * use grid configuration defined in {@code 
GRIDGAIN_HOME/config/default-config.xml}
+     * use grid configuration defined in {@code 
IGNITE_HOME/config/default-config.xml}
      * configuration file. If such file is not found, then all system defaults 
will be used.
      *
      * @param springCtx Optional Spring application context, possibly {@code 
null}.
@@ -431,7 +431,7 @@ public class GridGainEx {
         if (url != null)
             return start(DFLT_CFG, null, springCtx);
 
-        U.warn(null, "Default Spring XML file not found (is GRIDGAIN_HOME 
set?): " + DFLT_CFG);
+        U.warn(null, "Default Spring XML file not found (is IGNITE_HOME set?): 
" + DFLT_CFG);
 
         return start0(new GridStartContext(new IgniteConfiguration(), null, 
springCtx)).grid();
     }
@@ -582,7 +582,7 @@ public class GridGainEx {
             if (url == null)
                 throw new IgniteCheckedException("Spring XML configuration 
path is invalid: " + springCfgPath +
                     ". Note that this path should be either absolute or a 
relative local file system path, " +
-                    "relative to META-INF in classpath or valid URL to 
GRIDGAIN_HOME.", e);
+                    "relative to META-INF in classpath or valid URL to 
IGNITE_HOME.", e);
         }
 
         return loadConfigurations(url);
@@ -808,7 +808,7 @@ public class GridGainEx {
             if (url == null)
                 throw new IgniteCheckedException("Spring XML configuration 
path is invalid: " + springCfgPath +
                     ". Note that this path should be either absolute or a 
relative local file system path, " +
-                    "relative to META-INF in classpath or valid URL to 
GRIDGAIN_HOME.", e);
+                    "relative to META-INF in classpath or valid URL to 
IGNITE_HOME.", e);
         }
 
         return url;
@@ -1353,7 +1353,7 @@ public class GridGainEx {
             if (ggHome == null)
                 ggHome = U.getGridGainHome();
             else
-                // If user provided GRIDGAIN_HOME - set it as a system 
property.
+                // If user provided IGNITE_HOME - set it as a system property.
                 U.setGridGainHome(ggHome);
 
             U.setWorkDirectory(cfg.getWorkDirectory(), ggHome);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/internal/GridKernal.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/internal/util/ipc/shmem/GridIpcSharedMemoryServerEndpoint.java
 
b/modules/core/src/main/java/org/apache/ignite/internal/util/ipc/shmem/GridIpcSharedMemoryServerEndpoint.java
index 78fab34..41bc364 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/internal/util/ipc/shmem/GridIpcSharedMemoryServerEndpoint.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/internal/util/ipc/shmem/GridIpcSharedMemoryServerEndpoint.java
@@ -54,8 +54,8 @@ public class GridIpcSharedMemoryServerEndpoint implements 
GridIpcServerEndpoint
     public static final int DFLT_SPACE_SIZE = 256 * 1024;
 
     /**
-     * Default token directory. Note that this path is relative to {@code 
GRIDGAIN_HOME/work} folder
-     * if {@code GRIDGAIN_HOME} system or environment variable specified, 
otherwise it is relative to
+     * Default token directory. Note that this path is relative to {@code 
IGNITE_HOME/work} folder
+     * if {@code IGNITE_HOME} system or environment variable specified, 
otherwise it is relative to
      * {@code work} folder under system {@code java.io.tmpdir} folder.
      *
      * @see 
org.apache.ignite.configuration.IgniteConfiguration#getWorkDirectory()

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/internal/util/typedef/X.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/internal/util/typedef/X.java 
b/modules/core/src/main/java/org/apache/ignite/internal/util/typedef/X.java
index 6cf45e9..174ee4f 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/typedef/X.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/typedef/X.java
@@ -915,7 +915,7 @@ public final class X {
             return var;
         else
             throw new IgniteCheckedException("Failed to resolve GridGain home 
folder " +
-                "(please set 'GRIDGAIN_HOME' environment or system variable)");
+                "(please set 'IGNITE_HOME' environment or system variable)");
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/internal/visor/node/VisorBasicConfiguration.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/internal/visor/node/VisorBasicConfiguration.java
 
b/modules/core/src/main/java/org/apache/ignite/internal/visor/node/VisorBasicConfiguration.java
index ae68e38..ae1e1dd 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/internal/visor/node/VisorBasicConfiguration.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/internal/visor/node/VisorBasicConfiguration.java
@@ -39,7 +39,7 @@ public class VisorBasicConfiguration implements Serializable {
     /** Grid name. */
     private String gridName;
 
-    /** GRIDGAIN_HOME determined at startup. */
+    /** IGNITE_HOME determined at startup. */
     private String ggHome;
 
     /** Local host value used. */
@@ -151,14 +151,14 @@ public class VisorBasicConfiguration implements 
Serializable {
     }
 
     /**
-     * @return GRIDGAIN_HOME determined at startup.
+     * @return IGNITE_HOME determined at startup.
      */
     @Nullable public String ggHome() {
         return ggHome;
     }
 
     /**
-     * @param ggHome New GRIDGAIN_HOME determined at startup.
+     * @param ggHome New IGNITE_HOME determined at startup.
      */
     public void ggHome(@Nullable String ggHome) {
         this.ggHome = ggHome;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/jdbc/IgniteJdbcDriver.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/jdbc/IgniteJdbcDriver.java 
b/modules/core/src/main/java/org/apache/ignite/jdbc/IgniteJdbcDriver.java
index e89c119..8ea267c 100644
--- a/modules/core/src/main/java/org/apache/ignite/jdbc/IgniteJdbcDriver.java
+++ b/modules/core/src/main/java/org/apache/ignite/jdbc/IgniteJdbcDriver.java
@@ -66,7 +66,7 @@ import java.util.logging.*;
  * Note that cache name is case sensitive and you have to always specify it in 
quotes.
  * <h1 class="header">Dependencies</h1>
  * JDBC driver is located in main GridGain JAR and depends on all libraries 
located in
- * {@code GRIDGAIN_HOME/libs} folder. So if you are using JDBC driver in any 
external tool,
+ * {@code IGNITE_HOME/libs} folder. So if you are using JDBC driver in any 
external tool,
  * you have to add main GridGain JAR will all dependencies to its classpath.
  * <h1 class="header">Configuration</h1>
  * Internally JDBC driver <b>is based on GridGain Java client</b>. Therefore, 
all client

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java 
b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
index c9c68f5..b6366b1 100644
--- a/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
+++ b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
@@ -65,8 +65,8 @@ import org.apache.ignite.*;
  * <h1 class="header">Usage</h1>
  * If you need to tie your application logic into GridGain lifecycle,
  * you can configure lifecycle beans via standard grid configuration, add your
- * application library dependencies into {@code GRIDGAIN_HOME/libs} folder, and
- * simply start {@code GRIDGAIN_HOME/ggstart.{sh|bat}} scripts.
+ * application library dependencies into {@code IGNITE_HOME/libs} folder, and
+ * simply start {@code IGNITE_HOME/ggstart.{sh|bat}} scripts.
  * <p>
  * <h1 class="header">Configuration</h1>
  * Grid lifecycle beans can be configured programmatically as follows:

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
 
b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
index bee3a2e..84f2299 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
@@ -163,7 +163,7 @@ public class IgniteOptimizedMarshaller extends 
IgniteAbstractMarshaller {
 
     /**
      * Specifies a name of the file which lists all class names to be 
optimized.
-     * The file path can either be absolute path, relative to {@code 
GRIDGAIN_HOME},
+     * The file path can either be absolute path, relative to {@code 
IGNITE_HOME},
      * or specify a resource file on the class path.
      * <p>
      * The format of the file is class name per line, like this:

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiManagementMBean.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiManagementMBean.java
 
b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiManagementMBean.java
index e8c0111..71bbb1e 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiManagementMBean.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiManagementMBean.java
@@ -60,7 +60,7 @@ public interface IgniteSpiManagementMBean {
     public long getUpTime();
 
     /**
-     * Gets Gridgain installation home folder (i.e. ${GRIDGAIN_HOME});
+     * Gets Gridgain installation home folder (i.e. ${IGNITE_HOME});
      *
      * @return Gridgain installation home folder.
      */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java
 
b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java
index c7f8c68..8b99fd8 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java
@@ -103,8 +103,8 @@ import java.util.*;
 public class SharedFsCheckpointSpi extends IgniteSpiAdapter implements 
CheckpointSpi,
     SharedFsCheckpointSpiMBean {
     /**
-     * Default checkpoint directory. Note that this path is relative to {@code 
GRIDGAIN_HOME/work} folder
-     * if {@code GRIDGAIN_HOME} system or environment variable specified, 
otherwise it is relative to
+     * Default checkpoint directory. Note that this path is relative to {@code 
IGNITE_HOME/work} folder
+     * if {@code IGNITE_HOME} system or environment variable specified, 
otherwise it is relative to
      * {@code work} folder under system {@code java.io.tmpdir} folder.
      *
      * @see 
org.apache.ignite.configuration.IgniteConfiguration#getWorkDirectory()
@@ -168,7 +168,7 @@ public class SharedFsCheckpointSpi extends IgniteSpiAdapter 
implements Checkpoin
 
     /**
      * Sets path to a shared directory where checkpoints will be stored. The
-     * path can either be absolute or relative to {@code GRIDGAIN_HOME} system
+     * path can either be absolute or relative to {@code IGNITE_HOME} system
      * or environment variable.
      * <p>
      * If not provided, default value is {@link #DFLT_DIR_PATH}.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/sharedfs/TcpDiscoverySharedFsIpFinder.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/sharedfs/TcpDiscoverySharedFsIpFinder.java
 
b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/sharedfs/TcpDiscoverySharedFsIpFinder.java
index 976347d..9120a70 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/sharedfs/TcpDiscoverySharedFsIpFinder.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/sharedfs/TcpDiscoverySharedFsIpFinder.java
@@ -53,7 +53,7 @@ import java.util.concurrent.atomic.*;
 public class TcpDiscoverySharedFsIpFinder extends TcpDiscoveryIpFinderAdapter {
     /**
      * Default path for discovering of local nodes (testing only). Note that 
this path is relative to
-     * {@code GRIDGAIN_HOME/work} folder if {@code GRIDGAIN_HOME} system or 
environment variable specified,
+     * {@code IGNITE_HOME/work} folder if {@code IGNITE_HOME} system or 
environment variable specified,
      * otherwise it is relative to {@code work} folder under system {@code 
java.io.tmpdir} folder.
      *
      * @see 
org.apache.ignite.configuration.IgniteConfiguration#getWorkDirectory()

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/spi/swapspace/file/FileSwapSpaceSpi.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/spi/swapspace/file/FileSwapSpaceSpi.java
 
b/modules/core/src/main/java/org/apache/ignite/spi/swapspace/file/FileSwapSpaceSpi.java
index a5782ea..ea7cc9a 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/spi/swapspace/file/FileSwapSpaceSpi.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/spi/swapspace/file/FileSwapSpaceSpi.java
@@ -102,8 +102,8 @@ import static org.apache.ignite.events.IgniteEventType.*;
 @SuppressWarnings({"PackageVisibleInnerClass", "PackageVisibleField"})
 public class FileSwapSpaceSpi extends IgniteSpiAdapter implements 
SwapSpaceSpi, FileSwapSpaceSpiMBean {
     /**
-     * Default base directory. Note that this path is relative to {@code 
GRIDGAIN_HOME/work} folder
-     * if {@code GRIDGAIN_HOME} system or environment variable specified, 
otherwise it is relative to
+     * Default base directory. Note that this path is relative to {@code 
IGNITE_HOME/work} folder
+     * if {@code IGNITE_HOME} system or environment variable specified, 
otherwise it is relative to
      * {@code work} folder under system {@code java.io.tmpdir} folder.
      *
      * @see 
org.apache.ignite.configuration.IgniteConfiguration#getWorkDirectory()

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineStartup.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineStartup.java
 
b/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineStartup.java
index f0c3d29..993daa0 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineStartup.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineStartup.java
@@ -47,7 +47,7 @@ import static org.apache.ignite.internal.GridProductImpl.*;
  * parameter which is Spring XML configuration file path. You can run this 
class from command
  * line without parameters to get help message.
  * <p>
- * Note that scripts {@code ${GRIDGAIN_HOME}/bin/ggstart.{sh|bat}} shipped 
with GridGain use
+ * Note that scripts {@code ${IGNITE_HOME}/bin/ggstart.{sh|bat}} shipped with 
GridGain use
  * this startup and you can use them as an example.
  */
 @SuppressWarnings({"CallToSystemExit"})
@@ -164,7 +164,7 @@ public final class CommandLineStartup {
                 X.error(
                     "    -i              - interactive mode (choose 
configuration file from list).",
                     "    path            - path to Spring XML configuration 
file.",
-                    "                      Path can be absolute or relative to 
GRIDGAIN_HOME.",
+                    "                      Path can be absolute or relative to 
IGNITE_HOME.",
                     " ",
                     "Spring file should contain one bean definition of Java 
type",
                     "'org.gridgain.grid.GridConfiguration'. Note that bean 
will be",

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-1.xml
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-1.xml 
b/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-1.xml
index 9da4bc8..0103f7c 100644
--- a/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-1.xml
+++ b/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-1.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("path-to-this-file/example-benchmark.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-2.xml
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-2.xml 
b/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-2.xml
index 1763b91..5a2aece 100644
--- a/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-2.xml
+++ b/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-2.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("path-to-this-file/example-benchmark.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-3.xml
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-3.xml 
b/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-3.xml
index 31bf21f..041a003 100644
--- a/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-3.xml
+++ b/modules/core/src/test/config/benchmark/spring-cache-client-benchmark-3.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("path-to-this-file/example-benchmark.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/example-cache.xml
----------------------------------------------------------------------
diff --git a/modules/core/src/test/config/example-cache.xml 
b/modules/core/src/test/config/example-cache.xml
index 03be6e0..0382d07 100644
--- a/modules/core/src/test/config/example-cache.xml
+++ b/modules/core/src/test/config/example-cache.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} examples/config/example-cache.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} examples/config/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file to GridGain:
     GridGain.start("examples/config/example-cache.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/ggfs-loopback.xml
----------------------------------------------------------------------
diff --git a/modules/core/src/test/config/ggfs-loopback.xml 
b/modules/core/src/test/config/ggfs-loopback.xml
index 3b6d1d7..d736e31 100644
--- a/modules/core/src/test/config/ggfs-loopback.xml
+++ b/modules/core/src/test/config/ggfs-loopback.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} 
path-to-this-file/example-ggfs-loopback.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} 
path-to-this-file/example-ggfs-loopback.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("path-to-this-file/example-ggfs-loopback.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/ggfs-shmem.xml
----------------------------------------------------------------------
diff --git a/modules/core/src/test/config/ggfs-shmem.xml 
b/modules/core/src/test/config/ggfs-shmem.xml
index 22ab3b3..535b363 100644
--- a/modules/core/src/test/config/ggfs-shmem.xml
+++ b/modules/core/src/test/config/ggfs-shmem.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} 
path-to-this-file/example-ggfs-shmem.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-ggfs-shmem.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("path-to-this-file/example-ggfs-shmem.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/log4j-test.xml
----------------------------------------------------------------------
diff --git a/modules/core/src/test/config/log4j-test.xml 
b/modules/core/src/test/config/log4j-test.xml
index d9feb40..a1332f3 100644
--- a/modules/core/src/test/config/log4j-test.xml
+++ b/modules/core/src/test/config/log4j-test.xml
@@ -66,7 +66,7 @@
     -->
     <appender name="FILE" class="org.apache.log4j.RollingFileAppender">
         <param name="Threshold" value="DEBUG"/>
-        <param name="File" value="${GRIDGAIN_HOME}/work/log/gridgain.log"/>
+        <param name="File" value="${IGNITE_HOME}/work/log/gridgain.log"/>
         <param name="Append" value="true"/>
         <param name="MaxFileSize" value="10MB"/>
         <param name="MaxBackupIndex" value="10"/>

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/spring-cache-load.xml
----------------------------------------------------------------------
diff --git a/modules/core/src/test/config/spring-cache-load.xml 
b/modules/core/src/test/config/spring-cache-load.xml
index dc1f3fe..687a4c0 100644
--- a/modules/core/src/test/config/spring-cache-load.xml
+++ b/modules/core/src/test/config/spring-cache-load.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("path-to-this-file/example-benchmark.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/spring-multicache.xml
----------------------------------------------------------------------
diff --git a/modules/core/src/test/config/spring-multicache.xml 
b/modules/core/src/test/config/spring-multicache.xml
index f6e3dd8..f11b24f 100644
--- a/modules/core/src/test/config/spring-multicache.xml
+++ b/modules/core/src/test/config/spring-multicache.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("path-to-this-file/example-benchmark.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/streamer/average/spring-streamer-average-base.xml
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/config/streamer/average/spring-streamer-average-base.xml
 
b/modules/core/src/test/config/streamer/average/spring-streamer-average-base.xml
index a8fea8c..6675989 100644
--- 
a/modules/core/src/test/config/streamer/average/spring-streamer-average-base.xml
+++ 
b/modules/core/src/test/config/streamer/average/spring-streamer-average-base.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} examples/config/example-cache.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} examples/config/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("examples/config/example-cache.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/streamer/average/spring-streamer-average-local.xml
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/config/streamer/average/spring-streamer-average-local.xml
 
b/modules/core/src/test/config/streamer/average/spring-streamer-average-local.xml
index 1050318..aa9facd 100644
--- 
a/modules/core/src/test/config/streamer/average/spring-streamer-average-local.xml
+++ 
b/modules/core/src/test/config/streamer/average/spring-streamer-average-local.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} examples/config/example-cache.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} examples/config/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("examples/config/example-cache.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/streamer/average/spring-streamer-average-random.xml
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/config/streamer/average/spring-streamer-average-random.xml
 
b/modules/core/src/test/config/streamer/average/spring-streamer-average-random.xml
index bf09b25..53925db 100644
--- 
a/modules/core/src/test/config/streamer/average/spring-streamer-average-random.xml
+++ 
b/modules/core/src/test/config/streamer/average/spring-streamer-average-random.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} examples/config/example-cache.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} examples/config/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("examples/config/example-cache.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/streamer/spring-streamer-base.xml
----------------------------------------------------------------------
diff --git a/modules/core/src/test/config/streamer/spring-streamer-base.xml 
b/modules/core/src/test/config/streamer/spring-streamer-base.xml
index bd73aca..326124f 100644
--- a/modules/core/src/test/config/streamer/spring-streamer-base.xml
+++ b/modules/core/src/test/config/streamer/spring-streamer-base.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} examples/config/example-cache.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} examples/config/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("examples/config/example-cache.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/config/tests.properties
----------------------------------------------------------------------
diff --git a/modules/core/src/test/config/tests.properties 
b/modules/core/src/test/config/tests.properties
index 8b9eaa4..e629ba2 100644
--- a/modules/core/src/test/config/tests.properties
+++ b/modules/core/src/test/config/tests.properties
@@ -37,7 +37,7 @@ jboss.disco.test.wait=180000
 # You will either need to override deploy.uri.dir or supply CLASSES_URI as 
system property.
 #
 # Path to keystore with private and public keys.
-deploy.uri.secure.keystore=@{GRIDGAIN_HOME}/modules/tests/config/securedeploy/keystore
+deploy.uri.secure.keystore=@{IGNITE_HOME}/modules/tests/config/securedeploy/keystore
 # Temporary dir where deployment unit stored before deploy.
 deploy.uri.tmpdir=${java.io.tmpdir}/gg
 # Deployment dir for file scanner test with different types of GAR's.
@@ -45,7 +45,7 @@ deploy.uri.file2.path=${java.io.tmpdir}/gg/verification/
 # URI string.
 deploy.uri.file2=file://freq=200@localhost/${java.io.tmpdir}/gg/verification/
 # File scanner URI for local file deployment.
-deploy.uri.file=file://localhost/@{GRIDGAIN_HOME}/work/deployment/file/
+deploy.uri.file=file://localhost/@{IGNITE_HOME}/work/deployment/file/
 # FTP scanner URI for FTP deployment.
 deploy.uri.ftp=ftp://ftptest:iddqd@94.72.60.102:21/gg-test/deployment
 # Classes scanner URI for classes deployment. Must be overridden for every 
user.
@@ -62,7 +62,7 @@ ant.gar.descriptor.dir=modules/extdata/p2p/META-INF
 # Temporary directory for the Ant task resulting GAR file.
 ant.gar.tmpdir=${java.io.tmpdir}/gg
 # The same as p2p.uri.cls but without protocol
-ant.gar.srcdir=@{GRIDGAIN_HOME}/modules/extdata/uri/target/classes/
+ant.gar.srcdir=@{IGNITE_HOME}/modules/extdata/uri/target/classes/
 
 # GAR paths to use in URI deployment SPI tests
 ant.urideployment.gar.uri=file://freq=5000@localhost/EXTDATA/uri/deploy
@@ -70,7 +70,7 @@ ant.urideployment.gar.file=modules/extdata/uri/deploy/uri.gar
 ant.urideployment.gar.path=modules/extdata/uri/deploy/
 
 # Classpath directory for GridP2PUserVersionChangeSelfTest
-ant.userversion.class.dir=@{GRIDGAIN_HOME}/modules/tests/java/
+ant.userversion.class.dir=@{IGNITE_HOME}/modules/tests/java/
 
 # Multicast discovery self test.
 discovery.mbeanserver.selftest.baseport=50000
@@ -84,7 +84,7 @@ grid.comm.selftest.timeout=10000
 
 #P2P tests
 #Overwrite this property. It should point to P2P module compilation directory.
-p2p.uri.cls=file://localhost/@{GRIDGAIN_HOME}/modules/extdata/p2p/target/classes/
+p2p.uri.cls=file://localhost/@{IGNITE_HOME}/modules/extdata/p2p/target/classes/
 
 # AOP tests.
 # Connector port for RMI.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/java/org/apache/ignite/internal/util/GridStartupWithUndefinedGridGainHomeSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/internal/GridKernal.java 
b/modules/core/src/main/java/org/apache/ignite/internal/GridKernal.java
index 0ffa030..83fe9fa 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/GridKernal.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/GridKernal.java
@@ -2380,16 +2380,16 @@ public class GridKernal extends ClusterGroupAdapter 
implements GridEx, IgniteMBe
     }
 
     /**
      * Prints out VM arguments and GRIDGAIN_HOME in info mode.
      *
      * @param rtBean Java runtime bean.
      */
     private void ackVmArguments(RuntimeMXBean rtBean) {
         assert log != null;
 
         // Ack GRIDGAIN_HOME and VM arguments.
         if (log.isInfoEnabled()) {
-            log.info("GRIDGAIN_HOME=" + cfg.getGridGainHome());
+            log.info("IGNITE_HOME=" + cfg.getGridGainHome());
             log.info("VM arguments: " + rtBean.getInputArguments());
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/handlers/log/GridLogCommandHandler.java
----------------------------------------------------------------------
@@ -2380,16 +2380,16 @@ public class GridKernal extends ClusterGroupAdapter 
 
     /**
-     * Prints out VM arguments and GRIDGAIN_HOME in info mode.
+     * Prints out VM arguments and IGNITE_HOME in info mode.
      *
      * @param rtBean Java runtime bean.
@@ -2380,16 +2380,16 @@ public class GridKernal extends ClusterGroupAdapter 
         assert log != null;
 
-        // Ack GRIDGAIN_HOME and VM arguments.
+        // Ack IGNITE_HOME and VM arguments.
         if (log.isInfoEnabled()) {
diff --git 
a/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/handlers/log/GridLogCommandHandler.java
 
b/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/handlers/log/GridLogCommandHandler.java
index 3c65b6d..1b1002c 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/handlers/log/GridLogCommandHandler.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/handlers/log/GridLogCommandHandler.java
@@ -72,7 +72,7 @@ public class GridLogCommandHandler extends 
GridRestCommandHandlerAdapter {
                 accessibleFolders.add(new File(accessiblePath));
         }
         else if (log.isDebugEnabled())
-            log.debug("Neither restAccessibleFolders nor GRIDGAIN_HOME 
properties are not set, will not restrict " +
+            log.debug("Neither restAccessibleFolders nor IGNITE_HOME 
properties are not set, will not restrict " +
                 "log files access");
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/internal/util/GridConfigurationFinder.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/internal/util/GridConfigurationFinder.java
 
b/modules/core/src/main/java/org/apache/ignite/internal/util/GridConfigurationFinder.java
index 13f8aec..5e1cb39 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/internal/util/GridConfigurationFinder.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/internal/util/GridConfigurationFinder.java
@@ -25,7 +25,7 @@ import java.io.*;
 import java.util.*;
 
 /**
- * Finds configuration files located in {@code GRIDGAIN_HOME} folder
+ * Finds configuration files located in {@code IGNITE_HOME} folder
  * and its subfolders.
  */
 public final class GridConfigurationFinder {
@@ -46,7 +46,7 @@ public final class GridConfigurationFinder {
     }
 
     /**
-     * Lists paths to all GridGain configuration files located in 
GRIDGAIN_HOME with their
+     * Lists paths to all GridGain configuration files located in IGNITE_HOME 
with their
      * last modification timestamps.
      *
      * @return Collection of configuration files and their last modification 
timestamps.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/internal/util/GridUtils.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/internal/util/GridUtils.java 
b/modules/core/src/main/java/org/apache/ignite/internal/util/GridUtils.java
index f98fc40..8a39a21 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/GridUtils.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/GridUtils.java
@@ -2337,15 +2337,15 @@ public abstract class GridUtils {
      * @param e Exception.
      */
     private static void logResolveFailed(Class cls, Exception e) {
-        warn(null, "Failed to resolve GRIDGAIN_HOME automatically for class 
codebase " +
+        warn(null, "Failed to resolve IGNITE_HOME automatically for class 
codebase " +
             "[class=" + cls + (e == null ? "" : ", e=" + e.getMessage()) + 
']');
     }
 
     /**
-     * Retrieves {@code GRIDGAIN_HOME} property. The property is retrieved 
from system
+     * Retrieves {@code IGNITE_HOME} property. The property is retrieved from 
system
      * properties or from environment in that order.
      *
-     * @return {@code GRIDGAIN_HOME} property.
+     * @return {@code IGNITE_HOME} property.
      */
     @Nullable public static String getGridGainHome() {
         GridTuple<String> ggHomeTup = ggHome;
@@ -2405,18 +2405,18 @@ public abstract class GridUtils {
             ggHome0 = ggHomeTup.get();
 
         if (ggHome0 != null && !ggHome0.equals(path))
-            throw new IgniteException("Failed to set GRIDGAIN_HOME after it 
has been already resolved " +
+            throw new IgniteException("Failed to set IGNITE_HOME after it has 
been already resolved " +
                 "[ggHome=" + ggHome0 + ", newGgHome=" + path + ']');
     }
 
     /**
      * Gets file associated with path.
      * <p>
      * First check if path is relative to {@code GRIDGAIN_HOME}.
      * If not, check if path is absolute.
      * If all checks fail, then {@code null} is returned.
      * <p>
-     * See {@link #getGridGainHome()} for information on how {@code 
GRIDGAIN_HOME} is retrieved.
+     * See {@link #getGridGainHome()} for information on how {@code 
IGNITE_HOME} is retrieved.
      *
      * @param path Path to resolve.
      * @return Resolved path as file, or {@code null} if path cannot be 
resolved.
@@ -2425,7 +2425,7 @@ public abstract class GridUtils {
         assert path != null;
 
         /*
-         * 1. Check relative to GRIDGAIN_HOME specified in configuration, if 
any.
+         * 1. Check relative to IGNITE_HOME specified in configuration, if any.
          */
 
         String home = getGridGainHome();
@@ -2459,11 +2459,11 @@ public abstract class GridUtils {
     /**
      * Gets URL representing the path passed in. First the check is made if 
path is absolute.
      * If not, then the check is made if path is relative to {@code META-INF} 
folder in classpath.
      * If not, then the check is made if path is relative to ${GRIDGAIN_HOME}.
      * If all checks fail,
      * then {@code null} is returned, otherwise URL representing path is 
returned.
      * <p>
-     * See {@link #getGridGainHome()} for information on how {@code 
GRIDGAIN_HOME} is retrieved.
+     * See {@link #getGridGainHome()} for information on how {@code 
IGNITE_HOME} is retrieved.
      *
      * @param path Path to resolve.
      * @return Resolved path as URL, or {@code null} if path cannot be 
resolved.
@@ -2476,11 +2476,11 @@ public abstract class GridUtils {
     /**
      * Gets URL representing the path passed in. First the check is made if 
path is absolute.
      * If not, then the check is made if path is relative to {@code META-INF} 
folder in classpath.
      * If not, then the check is made if path is relative to ${GRIDGAIN_HOME}.
      * If all checks fail,
      * then {@code null} is returned, otherwise URL representing path is 
returned.
      * <p>
-     * See {@link #getGridGainHome()} for information on how {@code 
GRIDGAIN_HOME} is retrieved.
+     * See {@link #getGridGainHome()} for information on how {@code 
IGNITE_HOME} is retrieved.
      *
      * @param path Path to resolve.
      * @param metaInf Flag to indicate whether META-INF folder should be 
checked or class path root.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/main/java/org/apache/ignite/internal/util/ipc/shmem/GridIpcSharedMemoryServerEndpoint.java
----------------------------------------------------------------------
@@ -2405,18 +2405,18 @@ public abstract class GridUtils {
      * Gets file associated with path.
      * <p>
-     * First check if path is relative to {@code GRIDGAIN_HOME}.
+     * First check if path is relative to {@code IGNITE_HOME}.
      * If not, check if path is absolute.
      * If all checks fail, then {@code null} is returned.
@@ -2459,11 +2459,11 @@ public abstract class GridUtils {
      * If not, then the check is made if path is relative to {@code META-INF} 
folder in classpath.
-     * If not, then the check is made if path is relative to ${GRIDGAIN_HOME}.
+     * If not, then the check is made if path is relative to ${IGNITE_HOME}.
      * If all checks fail,
      * then {@code null} is returned, otherwise URL representing path is 
@@ -2476,11 +2476,11 @@ public abstract class GridUtils {
      * If not, then the check is made if path is relative to {@code META-INF} 
folder in classpath.
-     * If not, then the check is made if path is relative to ${GRIDGAIN_HOME}.
+     * If not, then the check is made if path is relative to ${IGNITE_HOME}.
      * If all checks fail,
      * then {@code null} is returned, otherwise URL representing path is 
diff --git 
a/modules/core/src/test/java/org/apache/ignite/internal/util/GridStartupWithUndefinedGridGainHomeSelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/internal/util/GridStartupWithUndefinedGridGainHomeSelfTest.java
index 0fc0ef4..33340f3 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/internal/util/GridStartupWithUndefinedGridGainHomeSelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/internal/util/GridStartupWithUndefinedGridGainHomeSelfTest.java
@@ -32,7 +32,7 @@ import static org.apache.ignite.IgniteSystemProperties.*;
 import static org.apache.ignite.internal.util.GridUtils.*;
 
 /**
- * Checks that node can be started without operations with undefined 
GRIDGAIN_HOME.
+ * Checks that node can be started without operations with undefined 
IGNITE_HOME.
  * <p>
  * Notes:
  * 1. The test intentionally extends JUnit {@link TestCase} class to make the 
test
@@ -84,7 +84,7 @@ public class GridStartupWithUndefinedGridGainHomeSelfTest 
extends TestCase {
 
             IgniteConfiguration cfg = new IgniteConfiguration();
 
-            // We have to explicitly configure path to license config because 
of undefined GRIDGAIN_HOME.
+            // We have to explicitly configure path to license config because 
of undefined IGNITE_HOME.
             cfg.setLicenseUrl("file:///" + ggHome + "/" + 
Ignition.DFLT_LIC_FILE_NAME);
 
             // Default console logger is used

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/java/org/apache/ignite/loadtest/GridSingleExecutionTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/loadtest/GridSingleExecutionTest.java
 
b/modules/core/src/test/java/org/apache/ignite/loadtest/GridSingleExecutionTest.java
index 8ca7e7e..c2bd8b0 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/loadtest/GridSingleExecutionTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/loadtest/GridSingleExecutionTest.java
@@ -184,7 +184,7 @@ public final class GridSingleExecutionTest {
 
         if (path == null) {
             throw new IgniteCheckedException("Spring XML configuration file 
path is invalid: " + new File(springCfgPath) +
-                ". Note that this path should be either absolute path or a 
relative path to GRIDGAIN_HOME.");
+                ". Note that this path should be either absolute path or a 
relative path to IGNITE_HOME.");
         }
 
         if (!path.isFile())

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/java/org/apache/ignite/loadtests/cache/GridCacheAbstractLoadTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/loadtests/cache/GridCacheAbstractLoadTest.java
 
b/modules/core/src/test/java/org/apache/ignite/loadtests/cache/GridCacheAbstractLoadTest.java
index f6b5904..10a5d1d 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/loadtests/cache/GridCacheAbstractLoadTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/loadtests/cache/GridCacheAbstractLoadTest.java
@@ -323,7 +323,7 @@ abstract class GridCacheAbstractLoadTest {
 
         if (path == null)
             throw new IgniteCheckedException("Spring XML configuration file 
path is invalid: " + new File(springCfgPath) +
-                ". Note that this path should be either absolute path or a 
relative path to GRIDGAIN_HOME.");
+                ". Note that this path should be either absolute path or a 
relative path to IGNITE_HOME.");
 
         if (!path.isFile())
             throw new IgniteCheckedException("Provided file path is not a 
file: " + path);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/java/org/apache/ignite/loadtests/capacity/spring-capacity-cache.xml
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/loadtests/capacity/spring-capacity-cache.xml
 
b/modules/core/src/test/java/org/apache/ignite/loadtests/capacity/spring-capacity-cache.xml
index 40b0309..00b787c 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/loadtests/capacity/spring-capacity-cache.xml
+++ 
b/modules/core/src/test/java/org/apache/ignite/loadtests/capacity/spring-capacity-cache.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("path-to-this-file/example-benchmark.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/java/org/apache/ignite/loadtests/colocation/spring-colocation.xml
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/loadtests/colocation/spring-colocation.xml
 
b/modules/core/src/test/java/org/apache/ignite/loadtests/colocation/spring-colocation.xml
index 71355a5..2d8a89d 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/loadtests/colocation/spring-colocation.xml
+++ 
b/modules/core/src/test/java/org/apache/ignite/loadtests/colocation/spring-colocation.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the 
following command:
-    {GRIDGAIN_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
+    {IGNITE_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("path-to-this-file/example-benchmark.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/java/org/apache/ignite/startup/GridRandomCommandLineLoader.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/startup/GridRandomCommandLineLoader.java
 
b/modules/core/src/test/java/org/apache/ignite/startup/GridRandomCommandLineLoader.java
index faee085..f20f7c6 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/startup/GridRandomCommandLineLoader.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/startup/GridRandomCommandLineLoader.java
@@ -297,7 +297,7 @@ public final class GridRandomCommandLineLoader {
 
         if (path == null)
             throw new IgniteCheckedException("Spring XML configuration file 
path is invalid: " + new File(springCfgPath) +
-                ". Note that this path should be either absolute path or a 
relative path to GRIDGAIN_HOME.");
+                ". Note that this path should be either absolute path or a 
relative path to IGNITE_HOME.");
 
         if (!path.isFile())
             throw new IgniteCheckedException("Provided file path is not a 
file: " + path);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/java/org/apache/ignite/startup/GridVmNodesStarter.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/startup/GridVmNodesStarter.java 
b/modules/core/src/test/java/org/apache/ignite/startup/GridVmNodesStarter.java
index bc3aea8..78637fa 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/startup/GridVmNodesStarter.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/startup/GridVmNodesStarter.java
@@ -190,7 +190,7 @@ public final class GridVmNodesStarter {
 
         if (path == null)
             throw new IgniteCheckedException("Spring XML configuration file 
path is invalid: " + new File(springCfgPath) +
-                ". Note that this path should be either absolute path or a 
relative path to GRIDGAIN_HOME.");
+                ". Note that this path should be either absolute path or a 
relative path to IGNITE_HOME.");
 
         if (!path.isFile())
             throw new IgniteCheckedException("Provided file path is not a 
file: " + path);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/java/org/apache/ignite/testframework/GridTestUtils.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/testframework/GridTestUtils.java 
b/modules/core/src/test/java/org/apache/ignite/testframework/GridTestUtils.java
index 2bce759..b161243 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/testframework/GridTestUtils.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/testframework/GridTestUtils.java
@@ -644,13 +644,13 @@ public final class GridTestUtils {
      */
     @SuppressWarnings({"ProhibitedExceptionThrown"})
     public static String getGridGainHome() throws Exception {
-        String ggHome = System.getProperty("GRIDGAIN_HOME");
+        String ggHome = System.getProperty("IGNITE_HOME");
 
         if (ggHome == null)
-            ggHome = System.getenv("GRIDGAIN_HOME");
+            ggHome = System.getenv("IGNITE_HOME");
 
         if (ggHome == null)
-            throw new Exception("GRIDGAIN_HOME parameter must be set either as 
system or environment variable.");
+            throw new Exception("IGNITE_HOME parameter must be set either as 
system or environment variable.");
 
         File dir = new File(ggHome);
 
@@ -792,10 +792,10 @@ public final class GridTestUtils {
 
     /**
      * Gets file representing the path passed in. First the check is made if 
path is absolute.
-     * If not, then the check is made if path is relative to ${GRIDGAIN_HOME}. 
If both checks fail,
+     * If not, then the check is made if path is relative to ${IGNITE_HOME}. 
If both checks fail,
      * then {@code null} is returned, otherwise file representing path is 
returned.
      * <p>
-     * See {@link #getGridGainHome()} for information on how {@code 
GRIDGAIN_HOME} is retrieved.
+     * See {@link #getGridGainHome()} for information on how {@code 
IGNITE_HOME} is retrieved.
      *
      * @param path Path to resolve.
      * @return Resolved path, or {@code null} if file cannot be resolved.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/java/org/apache/ignite/testframework/config/GridTestProperties.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/testframework/config/GridTestProperties.java
 
b/modules/core/src/test/java/org/apache/ignite/testframework/config/GridTestProperties.java
index 67d8a7b..1551807 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/testframework/config/GridTestProperties.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/testframework/config/GridTestProperties.java
@@ -32,12 +32,12 @@ import java.util.regex.*;
  * <ul>
  * <li>
  *     Default properties and log4j.xml configuration is loaded directly from
- *     {@code ${GRIDGAIN_HOME}/modules/tests/config} folder. Default 
properties can be
+ *     {@code ${IGNITE_HOME}/modules/tests/config} folder. Default properties 
can be
  *     accessed via {@link #getDefaultProperties()} and {@link 
#getDefaultProperty(String)} methods.
  *   </li>
  * <li>
  *     User is able to override any default property and log4j configuration in
- *     {@code ${GRIDGAIN_HOME}/modules/tests/config/${username}} folder, where 
{@code username}
+ *     {@code ${IGNITE_HOME}/modules/tests/config/${username}} folder, where 
{@code username}
  *     is the system user name. User properties can be accessed via {@link 
#getProperties()} and
  *     {@link #getProperties(String)} methods.
  *   </li>
@@ -65,14 +65,14 @@ public final class GridTestProperties {
 
     /** */
     static {
-        // Initialize GRIDGAIN_HOME system property.
-        String ggHome = System.getProperty("GRIDGAIN_HOME");
+        // Initialize IGNITE_HOME system property.
+        String ggHome = System.getProperty("IGNITE_HOME");
 
         if (ggHome == null || ggHome.isEmpty()) {
-            ggHome = System.getenv("GRIDGAIN_HOME");
+            ggHome = System.getenv("IGNITE_HOME");
 
             if (ggHome != null && !ggHome.isEmpty())
-                System.setProperty("GRIDGAIN_HOME", ggHome);
+                System.setProperty("IGNITE_HOME", ggHome);
         }
 
         // Load default properties.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d336959d/modules/core/src/test/java/org/apache/ignite/testframework/junits/logger/GridLog4jRollingFileAppender.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/testframework/junits/logger/GridLog4jRollingFileAppender.java
 
b/modules/core/src/test/java/org/apache/ignite/testframework/junits/logger/GridLog4jRollingFileAppender.java
index 7be2574..3960759 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/testframework/junits/logger/GridLog4jRollingFileAppender.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/testframework/junits/logger/GridLog4jRollingFileAppender.java
@@ -83,7 +83,7 @@ public class GridLog4jRollingFileAppender extends 
RollingFileAppender implements
 
         this.nodeId = nodeId;
 
-        if (fileName != null) { // fileName could be null if GRIDGAIN_HOME is 
not defined.
+        if (fileName != null) { // fileName could be null if IGNITE_HOME is 
not defined.
             if (baseFileName == null)
                 baseFileName = fileName;
 

Reply via email to